ProSHADE: Namespace Members

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

Here is a list of all documented namespace members with links to the namespaces they belong to:

### - i -

- initialiseAllMemory() : ProSHADE_internal_sphericalHarmonics
- initialiseFFTWPlans() : ProSHADE_internal_sphericalHarmonics
- initialiseInverseSHComputation() : ProSHADE_internal_overlay
- initialSplitDiscreteTransform() : ProSHADE_internal_sphericalHarmonics
- isAxisUnique() : ProSHADE_internal_maths
- isBandWithinShell() : ProSHADE_internal_distances
- isFileMAP() : ProSHADE_internal_io
- isFilePDB() : ProSHADE_internal_io
- isSymmetrySame() : ProSHADE_internal_symmetry